( cd opt/llvm-opt/bin ; rm -rf clang )
( cd opt/llvm-opt/bin ; ln -sf clang-20 clang )
( cd opt/llvm-opt/bin ; rm -rf clang++ )
( cd opt/llvm-opt/bin ; ln -sf clang clang++ )
( cd opt/llvm-opt/bin ; rm -rf clang-cl )
( cd opt/llvm-opt/bin ; ln -sf clang clang-cl )
( cd opt/llvm-opt/bin ; rm -rf clang-cpp )
( cd opt/llvm-opt/bin ; ln -sf clang clang-cpp )
( cd opt/llvm-opt/bin ; rm -rf ld.lld )
( cd opt/llvm-opt/bin ; ln -sf lld ld.lld )
( cd opt/llvm-opt/bin ; rm -rf ld64.lld )
( cd opt/llvm-opt/bin ; ln -sf lld ld64.lld )
( cd opt/llvm-opt/bin ; rm -rf lld-link )
( cd opt/llvm-opt/bin ; ln -sf lld lld-link )
( cd opt/llvm-opt/bin ; rm -rf llvm-addr2line )
( cd opt/llvm-opt/bin ; ln -sf llvm-symbolizer llvm-addr2line )
( cd opt/llvm-opt/bin ; rm -rf llvm-bitcode-strip )
( cd opt/llvm-opt/bin ; ln -sf llvm-objcopy llvm-bitcode-strip )
( cd opt/llvm-opt/bin ; rm -rf llvm-dlltool )
( cd opt/llvm-opt/bin ; ln -sf llvm-ar llvm-dlltool )
( cd opt/llvm-opt/bin ; rm -rf llvm-install-name-tool )
( cd opt/llvm-opt/bin ; ln -sf llvm-objcopy llvm-install-name-tool )
( cd opt/llvm-opt/bin ; rm -rf llvm-lib )
( cd opt/llvm-opt/bin ; ln -sf llvm-ar llvm-lib )
( cd opt/llvm-opt/bin ; rm -rf llvm-otool )
( cd opt/llvm-opt/bin ; ln -sf llvm-objdump llvm-otool )
( cd opt/llvm-opt/bin ; rm -rf llvm-ranlib )
( cd opt/llvm-opt/bin ; ln -sf llvm-ar llvm-ranlib )
( cd opt/llvm-opt/bin ; rm -rf llvm-readelf )
( cd opt/llvm-opt/bin ; ln -sf llvm-readobj llvm-readelf )
( cd opt/llvm-opt/bin ; rm -rf llvm-strip )
( cd opt/llvm-opt/bin ; ln -sf llvm-objcopy llvm-strip )
( cd opt/llvm-opt/bin ; rm -rf llvm-windres )
( cd opt/llvm-opt/bin ; ln -sf llvm-rc llvm-windres )
( cd opt/llvm-opt/bin ; rm -rf wasm-ld )
( cd opt/llvm-opt/bin ; ln -sf lld wasm-ld )
( cd opt/llvm-opt/lib64 ; rm -rf libLLVM-20.so )
( cd opt/llvm-opt/lib64 ; ln -sf libLLVM.so.20.1 libLLVM-20.so )
( cd opt/llvm-opt/lib64 ; rm -rf libLLVM.so )
( cd opt/llvm-opt/lib64 ; ln -sf libLLVM.so.20.1 libLLVM.so )
( cd opt/llvm-opt/lib64 ; rm -rf libLTO.so )
( cd opt/llvm-opt/lib64 ; ln -sf libLTO.so.20.1 libLTO.so )
( cd opt/llvm-opt/lib64 ; rm -rf libRemarks.so )
( cd opt/llvm-opt/lib64 ; ln -sf libRemarks.so.20.1 libRemarks.so )
( cd opt/llvm-opt/lib64 ; rm -rf libc++.so.1 )
( cd opt/llvm-opt/lib64 ; ln -sf libc++.so.1.0 libc++.so.1 )
( cd opt/llvm-opt/lib64 ; rm -rf libc++abi.so )
( cd opt/llvm-opt/lib64 ; ln -sf libc++abi.so.1 libc++abi.so )
( cd opt/llvm-opt/lib64 ; rm -rf libc++abi.so.1 )
( cd opt/llvm-opt/lib64 ; ln -sf libc++abi.so.1.0 libc++abi.so.1 )
( cd opt/llvm-opt/lib64 ; rm -rf libclang-cpp.so )
( cd opt/llvm-opt/lib64 ; ln -sf libclang-cpp.so.20.1 libclang-cpp.so )
( cd opt/llvm-opt/lib64 ; rm -rf libclang.so )
( cd opt/llvm-opt/lib64 ; ln -sf libclang.so.20.1 libclang.so )
( cd opt/llvm-opt/lib64 ; rm -rf libclang.so.20.1 )
( cd opt/llvm-opt/lib64 ; ln -sf libclang.so.20.1.8 libclang.so.20.1 )
( cd opt/llvm-opt/lib64 ; rm -rf liblldb.so )
( cd opt/llvm-opt/lib64 ; ln -sf liblldb.so.20.1 liblldb.so )
( cd opt/llvm-opt/lib64 ; rm -rf liblldb.so.20.1 )
( cd opt/llvm-opt/lib64 ; ln -sf liblldb.so.20.1.8 liblldb.so.20.1 )
( cd opt/llvm-opt/lib64 ; rm -rf liblldbIntelFeatures.so )
( cd opt/llvm-opt/lib64 ; ln -sf liblldbIntelFeatures.so.20.1 liblldbIntelFeatures.so )
( cd opt/llvm-opt/lib64/python3.9/site-packages/lldb ; rm -rf _lldb.cpython-39-x86_64-linux-gnu.so )
( cd opt/llvm-opt/lib64/python3.9/site-packages/lldb ; ln -sf ../../../liblldb.so _lldb.cpython-39-x86_64-linux-gnu.so )
( cd opt/llvm-opt/lib64/python3.9/site-packages/lldb ; rm -rf lldb-argdumper )
( cd opt/llvm-opt/lib64/python3.9/site-packages/lldb ; ln -sf ../../../../bin/lldb-argdumper lldb-argdumper )
( cd usr/lib64 ; rm -rf libLLVM-20.so )
( cd usr/lib64 ; ln -sf libLLVM.so.20.1 libLLVM-20.so )
( cd usr/lib64 ; rm -rf libLLVM.so.20.1 )
( cd usr/lib64 ; ln -sf ../../opt/llvm-opt/lib64/libLLVM.so.20.1 libLLVM.so.20.1 )
( cd usr/lib64 ; rm -rf libclang-cpp.so.20.1 )
( cd usr/lib64 ; ln -sf ../../opt/llvm-opt/lib64/libclang-cpp.so.20.1 libclang-cpp.so.20.1 )
( cd usr/lib64 ; rm -rf libclang.so.20.1 )
( cd usr/lib64 ; ln -sf libclang.so.20.1.8 libclang.so.20.1 )
( cd usr/lib64 ; rm -rf libclang.so.20.1.8 )
( cd usr/lib64 ; ln -sf ../../opt/llvm-opt/lib64/libclang.so.20.1.8 libclang.so.20.1.8 )
