#define CLANG_VERSION 20.1.8
#define CLANG_VERSION_STRING "20.1.8"
#define CLANG_VERSION_MAJOR 20
#define CLANG_VERSION_MAJOR_STRING "20"
#define CLANG_VERSION_MINOR 1
#define CLANG_VERSION_PATCHLEVEL 8
#define MAX_CLANG_ABI_COMPAT_VERSION 20
